# eric7.eric7_server

eric-ide Server.

This is the main Python script of the eric-ide server. This is a server to perform remote development (e.g. code hosted on another computer or through a docker container).

### Global Attributes

None

### Classes

None

### Functions

createArgumentParser | Function to create an argument parser.
main | Main entry point into the application.

## createArgumentParser

createArgumentParser()

Function to create an argument parser.

Return:
  created argument parser object

Return Type:
  argparse.ArgumentParser

Up

## main

main()

Main entry point into the application.

Up